package ch.hslu.appe.gui.model;

import java.util.ArrayList;

import javax.swing.table.AbstractTableModel;

import ch.hslu.appe.usermanagement.webservice.UserDto;
import ch.hslu.appe.webservice.consumer.UserManagementConsumerImpl;

/**
 * Customer Table Model.
 */
@SuppressWarnings("serial")
public class CustomerTableModel extends AbstractTableModel {

    private final String[] tableHeader;
    private Object[][] tableData;
    private ArrayList<UserDto> users;

    /**
     * Constructor.
     */
    public CustomerTableModel() {

        tableHeader = new String[] {"Id", "Anrede", "Name", "Rolle", "Status" };

        generateTableData();
    }

    /**
     * Gets the column class.
     * @param c colum
     * @return column class
     */
    @SuppressWarnings({ "unchecked", "rawtypes" })
    @Override
    public final Class getColumnClass(final int c) {
        return getValueAt(0, c).getClass();
    }

    /**
     * Gets the number of columns.
     * @return number of columns
     */
    @Override
    public final int getColumnCount() {
        return tableHeader.length;
    }

    /**
     * Gets the name of the column.
     * @param col column
     * @return name of the column
     */
    @Override
    public final String getColumnName(final int col) {
        return tableHeader[col];
    }

    /**
     * Gets the number of rows.
     * @return number of rows
     */
    @Override
    public final int getRowCount() {
        return tableData.length;
    }

    /**
     * Gets the Table Entry.
     * @param row row
     * @param col col
     * @return entry
     */
    @Override
    public final Object getValueAt(final int row, final int col) {
        return tableData[row][col];
    }

    @Override
    public final void setValueAt(final Object value, final int row, final int col) {
        tableData[row][col] = value;
        fireTableCellUpdated(row, col);
    }

    /**
     * Generate / Update Table Data.
     */
    public final void generateTableData() {

        users = UserManagementConsumerImpl.getInstance().getUsers();

        if (users == null) {
            return;
        }

        tableData = new Object[users.size()][5];

        for (int index = 0; index < users.size(); index++) {
            UserDto user = users.get(index);

            tableData[index][0] = user.getId();
            tableData[index][1] = user.getSalutation();
            tableData[index][2] = user.getPrename() + " " + user.getSurname();
            tableData[index][3] = user.getRole();
            tableData[index][4] = user.getState();
        }
    }

}
